import { ElementRef, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import * as Chartist from 'chartist';
/**
 * Possible chart types
 */
export declare type ChartType = 'Pie' | 'Bar' | 'Line';
export declare type ChartInterfaces = Chartist.IChartistPieChart | Chartist.IChartistBarChart | Chartist.IChartistLineChart;
export declare type ChartOptions = Chartist.IBarChartOptions | Chartist.ILineChartOptions | Chartist.IPieChartOptions;
export declare type ResponsiveOptionTuple = Chartist.IResponsiveOptionTuple<ChartOptions>;
export declare type ResponsiveOptions = ResponsiveOptionTuple[];
/**
 * Represent a chart event.
 * For possible values, check the Chartist docs.
 */
export interface ChartEvent {
    [eventName: string]: (data: any) => void;
}
export declare class ChartistComponent implements OnInit, OnChanges, OnDestroy {
    private elementRef;
    data: Chartist.IChartistData;
    type: ChartType;
    options: Chartist.IChartOptions;
    responsiveOptions: ResponsiveOptions;
    events: ChartEvent;
    chart: ChartInterfaces;
    constructor(elementRef: ElementRef);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private renderChart;
    private update;
    private bindEvents;
}
